@@ -46,6 +46,10 @@ struct _GeditEncoding
 	const gchar *name;
 };
 
+G_DEFINE_BOXED_TYPE (GeditEncoding, gedit_encoding,
+                     gedit_encoding_copy,
+                     gedit_encoding_free)
+
 /* 
  * The original versions of the following tables are taken from profterm 
  *
@@ -449,25 +453,73 @@ gedit_encoding_free (GeditEncoding *enc)
 	g_return_if_fail (enc != NULL);
 }
 
-/**
- * gedit_encoding_get_type:
- * 
- * Retrieves the GType object which is associated with the
- * #GeditEncoding class.
- * 
- * Return value: the GType associated with #GeditEncoding.
- **/
-GType 
-gedit_encoding_get_type (void)
+static gboolean
+data_exists (GSList         *list,
+	     const gpointer  data)
 {
-	static GType our_type = 0;
+	while (list != NULL)
+	{
+		if (list->data == data)
+			return TRUE;
 
-	if (!our_type)
-		our_type = g_boxed_type_register_static (
-			"GeditEncoding",
-			(GBoxedCopyFunc) gedit_encoding_copy,
-			(GBoxedFreeFunc) gedit_encoding_free);
+		list = g_slist_next (list);
+	}
 
-	return our_type;
-} 
+	return FALSE;
+}
 
+GSList *
+_gedit_encoding_strv_to_list (const gchar * const *enc_str)
+{
+	GSList *res = NULL;
+	gchar **p;
+	const GeditEncoding *enc;
+	
+	for (p = (gchar **)enc_str; p != NULL && *p != NULL; p++)
+	{
+		const gchar *charset = *p;
+
+		if (strcmp (charset, "CURRENT") == 0)
+			g_get_charset (&charset);
+
+		g_return_val_if_fail (charset != NULL, NULL);
+		enc = gedit_encoding_get_from_charset (charset);
+
+		if (enc != NULL)
+		{
+			if (!data_exists (res, (gpointer)enc))
+				res = g_slist_prepend (res, (gpointer)enc);
+
+		}
+	}
+
+	return g_slist_reverse (res);
+}
+
+gchar **
+_gedit_encoding_list_to_strv (const GSList *enc_list)
+{
+	GSList *l;
+	GPtrArray *array;
+
+	array = g_ptr_array_sized_new (g_slist_length ((GSList *)enc_list) + 1);
+
+	for (l = (GSList *)enc_list; l != NULL; l = g_slist_next (l))
+	{
+		const GeditEncoding *enc;
+		const gchar *charset;
+		
+		enc = (const GeditEncoding *)l->data;
+
+		charset = gedit_encoding_get_charset (enc);
+		g_return_val_if_fail (charset != NULL, NULL);
+
+		g_ptr_array_add (array, g_strdup (charset));
+	}
+
+	g_ptr_array_add (array, NULL);
+
+	return (gchar **)g_ptr_array_free (array, FALSE);
+}
+
+/* ex:ts=8:noet: */
