@@ -139,6 +139,11 @@ try_convert (GCharsetConverter *converter,
 	gboolean ret;
 	gsize out_size;
 
+	if (inbuf == NULL || inbuf_size == 0)
+	{
+		return FALSE;
+	}
+
 	err = NULL;
 	nread = 0;
 	nwritten = 0;
@@ -148,9 +153,9 @@ try_convert (GCharsetConverter *converter,
 	do
 	{
 		res = g_converter_convert (G_CONVERTER (converter),
-		                           inbuf + nread,
+		                           (gchar *)inbuf + nread,
 		                           inbuf_size - nread,
-		                           out + nwritten,
+		                           (gchar *)out + nwritten,
 		                           out_size - nwritten,
 		                           G_CONVERTER_INPUT_AT_END,
 		                           &bytes_read,
@@ -200,9 +205,17 @@ guess_encoding (GeditSmartCharsetConverter *smart,
 {
 	GCharsetConverter *conv = NULL;
 
+	if (inbuf == NULL || inbuf_size == 0)
+	{
+		smart->priv->is_utf8 = TRUE;
+		return NULL;
+	}
+
 	if (smart->priv->encodings != NULL &&
 	    smart->priv->encodings->next == NULL)
+	{
 		smart->priv->use_first = TRUE;
+	}
 
 	/* We just check the first block */
 	while (TRUE)
@@ -279,15 +292,15 @@ guess_encoding (GeditSmartCharsetConverter *smart,
 }
 
 static GConverterResult
-gedit_smart_charset_converter_convert (GConverter *converter,
-				       const void *inbuf,
-				       gsize       inbuf_size,
-				       void       *outbuf,
-				       gsize       outbuf_size,
-				       GConverterFlags flags,
-				       gsize      *bytes_read,
-				       gsize      *bytes_written,
-				       GError    **error)
+gedit_smart_charset_converter_convert (GConverter       *converter,
+				       const void       *inbuf,
+				       gsize             inbuf_size,
+				       void             *outbuf,
+				       gsize             outbuf_size,
+				       GConverterFlags   flags,
+				       gsize            *bytes_read,
+				       gsize            *bytes_written,
+				       GError          **error)
 {
 	GeditSmartCharsetConverter *smart = GEDIT_SMART_CHARSET_CONVERTER (converter);
 
@@ -390,6 +403,10 @@ gedit_smart_charset_converter_get_guessed (GeditSmartCharsetConverter *smart)
 	{
 		return (const GeditEncoding *)smart->priv->current_encoding->data;
 	}
+	else if (smart->priv->is_utf8)
+	{
+		return gedit_encoding_get_utf8 ();
+	}
 
 	return NULL;
 }
