@@ -29,10 +29,6 @@
 #include "gedit-tab-label.h"
 #include "gedit-close-button.h"
 
-#ifdef BUILD_SPINNER
-#include "gedit-spinner.h"
-#endif
-
 #define GEDIT_TAB_LABEL_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE((object), GEDIT_TYPE_TAB_LABEL, GeditTabLabelPrivate))
 
 /* Signals */
@@ -119,11 +115,12 @@ close_button_clicked_cb (GtkWidget     *widget,
 }
 
 static void
-sync_tip (GeditTab *tab, GeditTabLabel *tab_label)
+sync_tip (GeditTab *tab,
+	  GeditTabLabel *tab_label)
 {
 	gchar *str;
 
-	str = _gedit_tab_get_tooltips (tab);
+	str = _gedit_tab_get_tooltip (tab);
 	g_return_if_fail (str != NULL);
 
 	gtk_widget_set_tooltip_markup (tab_label->priv->ebox, str);
@@ -131,7 +128,9 @@ sync_tip (GeditTab *tab, GeditTabLabel *tab_label)
 }
 
 static void
-sync_name (GeditTab *tab, GParamSpec *pspec, GeditTabLabel *tab_label)
+sync_name (GeditTab      *tab,
+	   GParamSpec    *pspec,
+	   GeditTabLabel *tab_label)
 {
 	gchar *str;
 
@@ -147,7 +146,9 @@ sync_name (GeditTab *tab, GParamSpec *pspec, GeditTabLabel *tab_label)
 }
 
 static void
-sync_state (GeditTab *tab, GParamSpec *pspec, GeditTabLabel *tab_label)
+sync_state (GeditTab      *tab,
+	    GParamSpec    *pspec,
+	    GeditTabLabel *tab_label)
 {
 	GeditTabState  state;
 
@@ -169,11 +170,7 @@ sync_state (GeditTab *tab, GParamSpec *pspec, GeditTabLabel *tab_label)
 		gtk_widget_hide (tab_label->priv->icon);
 
 		gtk_widget_show (tab_label->priv->spinner);
-#ifdef BUILD_SPINNER
-		gedit_spinner_start (GEDIT_SPINNER (tab_label->priv->spinner));
-#else
 		gtk_spinner_start (GTK_SPINNER (tab_label->priv->spinner));
-#endif
 	}
 	else
 	{
@@ -188,11 +185,7 @@ sync_state (GeditTab *tab, GParamSpec *pspec, GeditTabLabel *tab_label)
 		gtk_widget_show (tab_label->priv->icon);
 
 		gtk_widget_hide (tab_label->priv->spinner);
-#ifdef BUILD_SPINNER
-		gedit_spinner_stop (GEDIT_SPINNER (tab_label->priv->spinner));
-#else
 		gtk_spinner_stop (GTK_SPINNER (tab_label->priv->spinner));
-#endif
 	}
 
 	/* sync tip since encoding is known only after load/save end */
@@ -255,7 +248,7 @@ gedit_tab_label_class_init (GeditTabLabelClass *klass)
 							      G_PARAM_READWRITE |
 							      G_PARAM_CONSTRUCT_ONLY));
 
-	g_type_class_add_private (object_class, sizeof(GeditTabLabelPrivate));
+	g_type_class_add_private (object_class, sizeof (GeditTabLabelPrivate));
 }
 
 static void
@@ -291,12 +284,7 @@ gedit_tab_label_init (GeditTabLabel *tab_label)
 			  G_CALLBACK (close_button_clicked_cb),
 			  tab_label);
 
-#ifdef BUILD_SPINNER
-	spinner = gedit_spinner_new ();
-	gedit_spinner_set_size (GEDIT_SPINNER (spinner), GTK_ICON_SIZE_MENU);
-#else
 	spinner = gtk_spinner_new ();
-#endif
 	gtk_box_pack_start (GTK_BOX (hbox), spinner, FALSE, FALSE, 0);
 	tab_label->priv->spinner = spinner;
 
@@ -369,4 +357,5 @@ gedit_tab_label_new (GeditTab *tab)
 
 	return GTK_WIDGET (tab_label);
 }
+
 /* ex:ts=8:noet: */
